==> tmdy_dll_0.0.0-031125.zip: TiMidity++-2.12.0-pre1b-031117-0200/libtimidity/instrum_prv.h <==
extern void alloc_instrument_bank(tmdy_struct_ex_t *tmdy_struct, int dr, int bankset);
static int load_missing_instruments(tmdy_struct_ex_t *tmdy_struct, int *rc);
static void free_instruments(tmdy_struct_ex_t *tmdy_struct, int reload_default_inst);
static void free_special_patch(tmdy_struct_ex_t *tmdy_struct, int id);
static int set_default_instrument(tmdy_struct_ex_t *tmdy_struct, char *name);
static void clear_magic_instruments(tmdy_struct_ex_t *tmdy_struct);
static Instrument *load_instrument(tmdy_struct_ex_t *tmdy_struct, int dr, int b, int prog);
extern void alloc_instrument_bank(tmdy_struct_ex_t *tmdy_struct, int dr, int bankset);
static int instrument_map(tmdy_struct_ex_t *tmdy_struct, 
				int mapID, int *set_in_out, int *elem_in_out);
static void set_instrument_map(tmdy_struct_ex_t *tmdy_struct, int mapID,
				int set_from, int elem_from, int set_to, int elem_to);
static void free_instrument_map(tmdy_struct_ex_t *tmdy_struct);
static AlternateAssign *add_altassign_string(tmdy_struct_ex_t *tmdy_struct, 
				AlternateAssign *old, char **params, int n);
static AlternateAssign *find_altassign(tmdy_struct_ex_t *tmdy_struct, 
				AlternateAssign *altassign, int note);
static void free_instrument(tmdy_struct_ex_t *tmdy_struct, Instrument *ip);

/* from smplfile.c */
extern Instrument *extract_sample_file(tmdy_struct_ex_t* tmdy_struct, char *);
extern int import_wave_discriminant(tmdy_struct_ex_t *tmdy_struct, char *sample_file);
extern int import_wave_load(tmdy_struct_ex_t *tmdy_struct, char *sample_file, Instrument *inst);
extern int import_aiff_discriminant(tmdy_struct_ex_t *tmdy_struct, char *sample_file);
extern int import_aiff_load(tmdy_struct_ex_t *tmdy_struct, char *sample_file, Instrument *inst);

/* from sndfont.c */
extern  Instrument *extract_soundfont(tmdy_struct_ex_t *tmdy_struct, 
				char *sf_file, int bank, int preset,int keynote);
extern  Instrument *load_soundfont_inst(tmdy_struct_ex_t *tmdy_struct, 
				int order, int bank, int preset,int keynote);

==> tmdy_dll_0.0.0-031126.zip: TiMidity++-2.12.0-pre1b-031117-0200/libtimidity/instrum_prv.h <==
extern void alloc_instrument_bank(tmdy_struct_ex_t *tmdy_struct, int dr, int bankset);
static int load_missing_instruments(tmdy_struct_ex_t *tmdy_struct, int *rc);
static void free_instruments(tmdy_struct_ex_t *tmdy_struct, int reload_default_inst);
static void free_special_patch(tmdy_struct_ex_t *tmdy_struct, int id);
static int set_default_instrument(tmdy_struct_ex_t *tmdy_struct, char *name);
static void clear_magic_instruments(tmdy_struct_ex_t *tmdy_struct);
static Instrument *load_instrument(tmdy_struct_ex_t *tmdy_struct, int dr, int b, int prog);
extern void alloc_instrument_bank(tmdy_struct_ex_t *tmdy_struct, int dr, int bankset);
static int instrument_map(tmdy_struct_ex_t *tmdy_struct, 
				int mapID, int *set_in_out, int *elem_in_out);
static void set_instrument_map(tmdy_struct_ex_t *tmdy_struct, int mapID,
				int set_from, int elem_from, int set_to, int elem_to);
static void free_instrument_map(tmdy_struct_ex_t *tmdy_struct);
static AlternateAssign *add_altassign_string(tmdy_struct_ex_t *tmdy_struct, 
				AlternateAssign *old, char **params, int n);
static AlternateAssign *find_altassign(tmdy_struct_ex_t *tmdy_struct, 
				AlternateAssign *altassign, int note);
static void free_instrument(tmdy_struct_ex_t *tmdy_struct, Instrument *ip);

/* from smplfile.c */
extern Instrument *extract_sample_file(tmdy_struct_ex_t* tmdy_struct, char *);
extern int import_wave_discriminant(tmdy_struct_ex_t *tmdy_struct, char *sample_file);
extern int import_wave_load(tmdy_struct_ex_t *tmdy_struct, char *sample_file, Instrument *inst);
extern int import_aiff_discriminant(tmdy_struct_ex_t *tmdy_struct, char *sample_file);
extern int import_aiff_load(tmdy_struct_ex_t *tmdy_struct, char *sample_file, Instrument *inst);

/* from sndfont.c */
extern  Instrument *extract_soundfont(tmdy_struct_ex_t *tmdy_struct, 
				char *sf_file, int bank, int preset,int keynote);
extern  Instrument *load_soundfont_inst(tmdy_struct_ex_t *tmdy_struct, 
				int order, int bank, int preset,int keynote);
/*
#undef timidity_mutex_lock
#undef timidity_mutex_unlock
#define timidity_mutex_lock(_m) 
#define timidity_mutex_unlock(_m) 
*/
